@@ -421,7 +421,10 @@ struct help_type help_table[] =
 		"         a brief description. Use #event %* to see the current list of available\n"
 		"         events you can use.\n"
 		"\n"
+		"         DATE                 %1 month - %3 day   %4 hour : %5 minute\n"
+		"         DAY                  %3 day\n"
 		"         END OF PATH\n"
+		"         HOUR                 %4 hour\n"
 		"         IAC <VAR> <VAR>\n"
 		"         IAC SB GMCP <MODULE> %0 data     %1 raw data\n"
 		"         IAC SB MSSP          %0 variable %1 value\n"
@@ -434,17 +437,24 @@ struct help_type help_table[] =
 		"         MAP ENTER ROOM <VAR> %0 new vnum %1 old vnum\n"
 		"         MAP EXIT ROOM        %0 old vnum %1 new vnum\n"
 		"         MAP EXIT ROOM <VAR>  %0 old vnum %1 new vnum\n"
+		"         MINUTE               %5 minute\n"
+		"         MONTH                %1 month\n"
 		"         PROGRAM START        %0 client name %1 client version\n"
 		"         PROGRAM TERMINATION\n"
 		"         RECEIVED INPUT       %0 raw text\n"
 		"         RECEIVED LINE        %0 raw text %1 plain text\n"
 		"         RECEIVED OUTPUT      %0 raw text\n"
+		"         RECEIVED PROMPT      %0 raw text %1 plain text\n"
 		"         SCREEN RESIZE        %0 cols %1 rows\n"
+		"         SECOND               %6 second\n"
 		"         SEND OUTPUT          %0 raw text\n"
 		"         SESSION ACTIVATED    %0 name\n"
 		"         SESSION CONNECTED    %0 name %1 host %2 ip %3 port\n"
 		"         SESSION DEACTIVATED  %0 name\n"
 		"         SESSION DISCONNECTED %0 name %1 host %2 ip %3 port\n"
+		"         TIME                 %4 hour : %5 minute : %6 second\n"
+		"         WEEK                 %2 week\n"
+		"         YEAR                 %0 year\n"
 		"\n"
 		"<178>Example<078>: #event {SESSION CONNECTED} {#read mychar.tin}\n"
 		"\n"
@@ -497,6 +507,7 @@ struct help_type help_table[] =
 		"         #format {test} {%t}   {format}  display time with strftime format\n"
 		"         #format {test} {%u}   {string}  uppercase text\n"
 		"         #format {test} {%w}   {string}  wordwrap text\n"
+		"         #format {test} {%A}     {char}  print corresponding ascii value\n"
 		"         #format {cols} {%C}         {}  store the screen width in {cols}\n"
 		"         #format {test} {%L}   {string}  store the string length in {test}\n"
 		"         #format {rows} {%R}         {}  store the screen height in {rows}\n"
@@ -511,17 +522,16 @@ struct help_type help_table[] =
 		"         replace the function call with the line of text generated by the\n"
 		"         function.\n"
 		"\n"
-		"         Be aware that each function should set the $result variable.\n"
+		"         Be aware that each function should set the $result variable at the\n"
+		"         end of the function, or call #return with the given result.\n"
 		"\n"
 		"         To use a function use the @ character before the function name.\n"
 		"         The function arguments should be placed between braces behind the\n"
-		"         function name.\n"
+		"         function name with argument separated by semi-colons.\n"
 		"\n"
 		"         The function itself can use the provided arguments which are stored\n"
 		"         in %1 to %9, with %0 holding all arguments.\n"
 		"\n"
-		"         Currently you can't use a function from within another function\n"
-		"\n"
 		"<178>Example<078>: #function {rnd} {#math {result} {1 d (%2 - %1 + 1) + %1 - 1}}\n"
 		"         #showme A random number between 100 and 200: @rnd{100 200}\n"
 		"\n"
@@ -552,10 +562,11 @@ struct help_type help_table[] =
 		"<068>      #<078>         Code by Peter Unold, Bill Reis, David A. Wagner,         <068>#\n"
 		"<068>      #<078>      Rob Ellsworth, Jeremy C. Jack, and Igor van den Hoven.      <068>#\n"
 		"<068>      #<078>                                                                  <068>#\n"
-		"<068>      #<078>                             1992, 2011                           <068>#\n"
+		"<068>      #<078>                             1992, 2012                           <068>#\n"
 		"<068>      #<068>##################################################################<068>#<088>\n"
 	},
 */
+
 	{
 		"GREETING",
 		"<068>      #<068>##################################################################<068>#\n"
@@ -596,12 +607,18 @@ struct help_type help_table[] =
 		"<178>Command<078>: #highlight <178>{<078>string<178>}<078> <178>{<078>color names<178>}<078>\n"
 		"\n"
 		"         The highlight command is used to allow you to highlight strings of text\n"
-		"         from the mud.  Available color names are:\n"
+		"         from the mud.  Available ANSI color names are:\n"
 		"\n"
 		"         reset, light, faint, underscore, blink, reverse, dim,\n"
 		"         black, red, green, yellow, blue, magenta, cyan, white,\n"
 		"         b black, b red, b green, b yellow, b blue, b magenta, b cyan, b white\n"
 		"\n"
+		"         Available xterm 256 color names are:\n"
+		"\n"
+		"         dark azure, dark ebony, dark jade, dark lime, dark orange, dark silver,\n"
+		"         dark tan, dark violet, light azure, light ebony, light jade, light lime,\n"
+		"         light orange, light silver, light tan, light violet.\n"
+		"\n"
 		"         The %1-99 variables can be used as 'wildcards' that will match with any\n"
 		"         text. They are useful for highlighting a complete line. The %0 variable\n"
 		"         should never be used in highlights.\n"
@@ -705,6 +722,9 @@ struct help_type help_table[] =
 		"         #line ignore {argument}                Argument is executed without\n"
 		"                                                any triggers being checked.\n"
 		"\n"
+		"         #line strip {argument}                 Strips the argument next\n"
+		"                                                executes it a command.\n"
+		"\n"
 		"         #line substitute {options} {argument}  Substitutes the given options:\n"
 		"                                                variables, functions, colors,\n"
 		"                                                escapes, secure, eol, lnf, in\n"
@@ -816,15 +836,16 @@ struct help_type help_table[] =
 		"\n"
 		"         #map delete <direction>: Deletes the room in the given direction.\n"
 		"\n"
-		"         #map dig <direction> [new|<vnum>]: Creates an exit in the given\n"
+		"         #map dig <direction|vnum> [new|<vnum>]: Creates an exit in the given\n"
 		"                  direction. If no valid direction is given or no existing room\n"
 		"                  is found a new room is created. Useful for portal links and\n"
 		"                  other alternative forms of transportation. If the 'new'\n"
 		"                  argument is provided all existing rooms are ignored. If a\n"
 		"                  room vnum is given as the second argument an exit will be\n"
-		"                  created to the given room vnum.\n"
+		"                  created to the given room vnum. If the direction argument is\n"
+		"                  a valid unused vnum that room is created.\n"
 		"\n"
-		"         #map exit <exit> <COMMAND|DIRECTION|FLAG|GET|NAME|SET|VNUM> <argument>\n"
+		"         #map exit <exit> <COMMAND|DIRECTION|FLAG|GET|NAME|SAVE|SET|VNUM> <arg>\n"
 		"                  Set the exit data. Useful with a closed door where you can\n"
 		"                  set the exit command: '#map exit e command {open east;e}'.\n"
 		"\n"
@@ -837,12 +858,12 @@ struct help_type help_table[] =
 		"                  intersection is found. The route is stored in #path and can\n"
 		"                  subsequently be used with #walk\n"
 		"\n"
-		"         #map find <roomname> <exits> <roomdesc> <roomarea> <roomnote> Searches\n"
-		"                  for the given room name. If found the shortest path from your\n"
-		"                  current location to the target location is calculated. The\n"
-		"                  route is stored in #path and can subsequently be used with the\n"
-		"                  various #path commands. If <exits> is provided all exits must\n"
-		"                  be matched, if <roomdesc>, <roomarea> or <roomnote> is\n"
+		"         #map find <name> <exits> <desc> <area> <note> <terrain>\n"
+		"                  searches for the given room name. If found the shortest path\n"
+		"                  from your current location to the destination is calculated.\n"
+		"                  The route is stored in #path and can subsequently be used with\n"
+		"                  the various #path commands. If <exits> is provided all exits\n"
+		"                  must be matched, if <roomdesc>, <roomarea> or <roomnote> is\n"
 		"                  provided these are matched as well against the room to be\n"
 		"                  found. These options are also available to the goto, and link\n"
 		"                  commands.\n"
@@ -867,8 +888,11 @@ struct help_type help_table[] =
 		"                  screen if you have one. You can create a 16 rows high top\n"
 		"                  screen by using '#split 16 1'.\n"
 		"\n"
-		"         #map goto <room name> [exits]: Takes you to the given room name, if\n"
-		"                  you provide exits those must match as well.\n"
+		"         #map goto <room vnum> [dig]: Takes you to the given room vnum, with the\n"
+		"                  dig argument a new room will be created if non exists.\n"
+		"\n"
+		"         #map goto <name> <exits> <desc> <area> <note> <terrain>: Takes you to\n"
+		"                  the given room name, if you provide exits those must match.\n"
 		"\n"
 		"         #map get <option> <variable> [vnum]: Store a map value into a\n"
 		"                    variable, if no vnum is given the current room is used.\n"
@@ -896,11 +920,14 @@ struct help_type help_table[] =
 		"                  font for drawing characters use:\n"
 		"                  #loop 32 255 cnt {#echo {%-3s  %a} $cnt $cnt}\n"
 		"\n"
-		"         #map link <direction> <room name>: Links two rooms. If a valid\n"
-		"                  direction is given the link is two way.\n"
+		"         #map link <direction> <room name> [both]: Links two rooms. If the both\n"
+		"                  argument and a valid direction is given the link is two way.\n"
 		"\n"
-		"         #map list <roomname> <exits> <roomdesc> <roomarea> <roomnote>: Lists\n"
-		"                  all matching rooms and their distance.\n"
+		"         #map list <name> <exits> <desc> <area> <note> <terrain>\n"
+		"                  Lists all matching rooms and their distance.\n"
+		"\n"
+		"                  Use {variable} {<variable>} to save the output to a variable.\n"
+		"                  {roomname} {<name>}, {roomarea} {<area>}, etc, are valid too.\n"
 		"\n"
 		"         #map map {<x>x<y>} {filename} {a}: shows a map of surrounding rooms.\n"
 		"                  The {horizontal x vertical} argument i.e 80x25 is optional,\n"
@@ -964,7 +991,10 @@ struct help_type help_table[] =
 		"                  way so you can have the map properly display no exit rooms and\n"
 		"                  mazes.\n"
 		"                  If you use the both argument the exit is removed two-ways.\n"
-
+		"\n"
+		"         #map vnum <low> [high]: Change the room vnum to the given number, if\n"
+		"                  a range is provided the first available room in that range\n"
+		"                  is selected.\n"
 		"\n"
 		"         #map write <filename>: Will save the map.\n"
 	},
@@ -1427,6 +1457,8 @@ struct help_type help_table[] =
 		"\n"
 		"         Executes given command every # of seconds.\n"
 		"\n"
+		"<178>Comment<078>: Tickers don't work in the startup session.\n"
+		"\n"
 		"<178>Comment<078>: You can remove a ticker with the #unticker command.\n"
 	},
 	{
@@ -1527,7 +1559,7 @@ DO_COMMAND(do_help)
 			}
 			cat_sprintf(add, "%19s", help_table[cnt].name);
 		}
-		tintin_puts2(ses, add);
+		tintin_puts(ses, add);
 	}
 	else
 	{
