@@ -512,10 +512,12 @@ char *space_out(char *string)
 
 char *get_arg_to_brackets(struct session *ses, char *string, char *result)
 {
-	char *pti, *pto;
+	char *pti, *pto, *ptii, *ptoo;
+	int nest1 = 0, nest2 = 0, nest3 = 0;
 
 	pti = space_out(string);
 	pto = result;
+	ptii = NULL;
 
 	while (*pti)
 	{
@@ -528,7 +530,39 @@ char *get_arg_to_brackets(struct session *ses, char *string, char *result)
 
 		if (*pti == '[')
 		{
-			break;
+			nest2++;
+
+			if (nest1 == 0 && ptii == NULL)
+			{
+				ptii = pti;
+				ptoo = pto;
+			}
+		}
+		else if (*pti == ']')
+		{
+			if (nest2)
+			{
+				nest2--;
+			}
+			else
+			{
+				nest3 = 1;
+			}
+
+			if (*(pti+1) == 0 && ptii && nest1 == 0 && nest2 == 0 && nest3 == 0)
+			{
+				*ptoo = 0;
+
+				return ptii;
+			}
+		}
+		else if (*pti == DEFAULT_OPEN)
+		{
+			nest1++;
+		}
+		else if (*pti == DEFAULT_CLOSE)
+		{
+			nest1--;
 		}
 		*pto++ = *pti++;
 	}
@@ -668,9 +702,12 @@ void write_mud(struct session *ses, char *command, int flags)
 
 	if (ses->map && ses->map->in_room && ses->map->nofollow == 0)
 	{
-		if (follow_map(ses, command))
+		if (!HAS_BIT(ses->map->flags, MAP_FLAG_NOFOLLOW))
 		{
-			return;
+			if (follow_map(ses, command))
+			{
+				return;
+			}
 		}
 	}
 
@@ -697,8 +734,6 @@ void do_one_line(char *line, struct session *ses)
 
 	strip_vt102_codes(line, strip);
 
-	check_all_events(ses, SUB_ARG|SUB_SEC, 0, 2, "RECEIVED LINE", line, strip);
-
 	if (!HAS_BIT(ses->list[LIST_ACTION]->flags, LIST_FLAG_IGNORE))
 	{
 		check_all_actions(ses, line, strip);
@@ -727,6 +762,14 @@ void do_one_line(char *line, struct session *ses)
 		check_all_highlights(ses, line, strip);
 	}
 
+	if (ses->logline)
+	{
+		logit(ses, line, ses->logline, TRUE);
+
+		fclose(ses->logline);
+		ses->logline = NULL;
+	}
+
 	pop_call();
 	return;
 }
