@@ -35,20 +35,16 @@
 #endif
 #endif
 
-extern char **environ;
-
 DO_COMMAND(do_run)
 {
 	char left[BUFFER_SIZE], right[BUFFER_SIZE], temp[BUFFER_SIZE];
-	int desc;
+	int desc, pid;
 	struct winsize size;
 
 	char *argv[4] = {"sh", "-c", "", NULL};
 
-	arg = get_arg_in_braces(arg, left,  FALSE);
-	substitute(ses, left, left, SUB_VAR|SUB_FUN);
-	arg = get_arg_in_braces(arg, right, TRUE);
-	substitute(ses, right, right, SUB_VAR|SUB_FUN);
+	arg = sub_arg_in_braces(ses, arg, left,  GET_ONE, SUB_VAR|SUB_FUN);
+	arg = sub_arg_in_braces(ses, arg, right, GET_ALL, SUB_VAR|SUB_FUN);
 
 	if (*left == 0 || *right == 0)
 	{
@@ -60,7 +56,10 @@ DO_COMMAND(do_run)
 	size.ws_row = get_scroll_size(ses);
 	size.ws_col = ses->cols;
 
-	switch(forkpty(&desc, NULL, &gtd->old_terminal, &size))
+	pid = forkpty(&desc, temp, &gtd->old_terminal, &size);
+//	pid = forkpty(&desc, temp, &gtd->new_terminal, &size);
+
+	switch (pid)
 	{
 		case -1:
 			perror("forkpty");
@@ -69,11 +68,15 @@ DO_COMMAND(do_run)
 		case 0:
 			sprintf(temp, "exec %s", right);
 			argv[2] = temp;
-			execve("/bin/sh", argv, environ);
+			execv("/bin/sh", argv);
 			break;
 
 		default:
-			ses = new_session(ses, left, right, desc);
+			sprintf(temp, "{%s} {%d}", right, pid);
+
+			ses = new_session(ses, left, temp, desc);
+
+
 			break;
 	}
 	return gtd->ses;
@@ -84,7 +87,7 @@ DO_COMMAND(do_scan)
 	FILE *fp;
 	char filename[BUFFER_SIZE];
 
-	get_arg_in_braces(arg, filename, TRUE);
+	get_arg_in_braces(ses, arg, filename, TRUE);
 	substitute(ses, filename, filename, SUB_VAR|SUB_FUN);
 
 	if ((fp = fopen(filename, "r")) == NULL)
@@ -119,11 +122,11 @@ DO_COMMAND(do_scan)
 
 DO_COMMAND(do_script)
 {
-	char arg1[BUFFER_SIZE], arg2[BUFFER_SIZE], *cptr, buffer[BUFFER_SIZE], var[BUFFER_SIZE];
+	char arg1[BUFFER_SIZE], arg2[BUFFER_SIZE], *cptr, buf[BUFFER_SIZE], var[BUFFER_SIZE], tmp[BUFFER_SIZE];
 	FILE *script;
 	int index;
 
-	arg = sub_arg_in_braces(ses, arg, arg1, GET_ALL, SUB_VAR|SUB_FUN);
+	arg = sub_arg_in_braces(ses, arg, arg1, GET_ONE, SUB_VAR|SUB_FUN);
 	arg = sub_arg_in_braces(ses, arg, arg2, GET_ALL, SUB_VAR|SUB_FUN);
 
 	if (*arg1 == 0)
@@ -134,16 +137,16 @@ DO_COMMAND(do_script)
 	{
 		script = popen(arg1, "r");
 
-		while (fgets(buffer, BUFFER_SIZE - 1, script))
+		while (fgets(buf, BUFFER_SIZE - 1, script))
 		{
-			cptr = strchr(buffer, '\n');
+			cptr = strchr(buf, '\n');
 
 			if (cptr)
 			{
 				*cptr = 0;
 			}
 
-			ses = script_driver(ses, -1, buffer);
+			ses = script_driver(ses, -1, buf);
 		}
 
 		pclose(script);
@@ -156,16 +159,21 @@ DO_COMMAND(do_script)
 
 		var[0] = 0;
 
-		while (fgets(buffer, BUFFER_SIZE - 1, script))
+		while (fgets(buf, BUFFER_SIZE - 1, script))
 		{
-			cptr = strchr(buffer, '\n');
+			cptr = strchr(buf, '\n');
 
 			if (cptr)
 			{
 				*cptr = 0;
 			}
-			cat_sprintf(var, "{%d}{%s}", index++, buffer);
+
+			substitute(ses, buf, tmp, SUB_SEC);
+
+			cat_sprintf(var, "{%d}{%s}", index++, tmp);
 		}
+
+
 		set_nest_node(ses->list[LIST_VARIABLE], arg1, "%s", var);
 
 		pclose(script);
@@ -179,7 +187,7 @@ DO_COMMAND(do_system)
 {
 	char left[BUFFER_SIZE];
 
-	get_arg_in_braces(arg, left, TRUE);
+	get_arg_in_braces(ses, arg, left, TRUE);
 	substitute(ses, left, left, SUB_VAR|SUB_FUN);
 
 	if (*left == 0)
@@ -216,10 +224,10 @@ DO_COMMAND(do_textin)
 	FILE *fp;
 	char left[BUFFER_SIZE], right[BUFFER_SIZE], buffer[BUFFER_SIZE], *cptr;
 
-	arg = get_arg_in_braces(arg, left, FALSE);
+	arg = get_arg_in_braces(ses, arg, left, FALSE);
 	substitute(ses, left, left, SUB_VAR|SUB_FUN);
 
-	arg = get_arg_in_braces(arg, right, TRUE);
+	arg = get_arg_in_braces(ses, arg, right, TRUE);
 
 	if ((fp = fopen(left, "r")) == NULL)
 	{
