@@ -32,21 +32,15 @@
 #include "tintin.h"
 
 
-int match(struct session *ses, char *str, char *exp)
+int match(struct session *ses, char *str, char *exp, int flags)
 {
 	char expbuf[BUFFER_SIZE];
 
-	if (ses)
-	{
-		sprintf(expbuf, "^%s$", exp);
+	sprintf(expbuf, "^%s$", exp);
 
-		substitute(ses, expbuf, expbuf, SUB_VAR|SUB_FUN);
-	}
-	else
-	{
-		sprintf(expbuf, "^%s$", exp);
-	}
-	return tintin_regexp(NULL, str, expbuf, 0, 0);
+	substitute(ses, expbuf, expbuf, flags);
+
+	return tintin_regexp(ses, NULL, str, expbuf, 0, 0);
 }
 
 int find(struct session *ses, char *str, char *exp, int sub)
@@ -58,11 +52,11 @@ int find(struct session *ses, char *str, char *exp, int sub)
 		substitute(ses, str, strbuf, SUB_VAR|SUB_FUN);
 		substitute(ses, exp, expbuf, SUB_VAR|SUB_FUN);
 
-		return tintin_regexp(NULL, strbuf, expbuf, 0, sub);
+		return tintin_regexp(ses, NULL, strbuf, expbuf, 0, sub);
 	}
 	else
 	{
-		return tintin_regexp(NULL, str, exp, 0, sub);
+		return tintin_regexp(ses, NULL, str, exp, 0, sub);
 	}
 }
 
@@ -70,10 +64,10 @@ DO_COMMAND(do_regexp)
 {
 	char left[BUFFER_SIZE], right[BUFFER_SIZE], is_true[BUFFER_SIZE], is_false[BUFFER_SIZE];
 
-	arg = get_arg_in_braces(arg, left,  0);
-	arg = get_arg_in_braces(arg, right, 0);
-	arg = get_arg_in_braces(arg, is_true,  1);
-	arg = get_arg_in_braces(arg, is_false, 1);
+	arg = get_arg_in_braces(ses, arg, left,  0);
+	arg = get_arg_in_braces(ses, arg, right, 0);
+	arg = get_arg_in_braces(ses, arg, is_true,  1);
+	arg = get_arg_in_braces(ses, arg, is_false, 1);
 
 	if (*is_true == 0)
 	{
@@ -84,7 +78,7 @@ DO_COMMAND(do_regexp)
 		substitute(ses, left,  left,  SUB_VAR|SUB_FUN);
 		substitute(ses, right, right, SUB_VAR|SUB_FUN);
 
-		if (tintin_regexp(NULL, left, right, 0, SUB_CMD))
+		if (tintin_regexp(ses, NULL, left, right, 0, SUB_CMD))
 		{
 			substitute(ses, is_true, is_true, SUB_CMD);
 
@@ -190,7 +184,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 {
 	struct listnode *node;
 	char temp[BUFFER_SIZE], buf[BUFFER_SIZE], buffer[BUFFER_SIZE], *pti, *pto, *ptt;
-	char *pte;
+	char *pte, old[6] = { 0 };
 	int i, cnt, escape = FALSE, flags_neol = flags;
 
 	push_call("substitute(%p,%p,%p,%d)",ses,string,result,flags);
@@ -202,18 +196,12 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 
 	while (TRUE)
 	{
-
-#ifdef BIG5
-		if (*pti & 0x80)
+		if (HAS_BIT(ses->flags, SES_FLAG_BIG5) && *pti & 128 && pti[1] != 0)
 		{
 			*pto++ = *pti++;
-			if (*pti)
-			{
-				*pto++ = *pti++;
-			}
+			*pto++ = *pti++;
 			continue;
 		}
-#endif
 
 		switch (*pti)
 		{
@@ -250,6 +238,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 				{
 					return pto - result;
 				}
+				break;
 
 			case '$':
 				if (HAS_BIT(flags, SUB_VAR) && (pti[1] == DEFAULT_OPEN || isalpha((int) pti[1]) || pti[1] == '$'))
@@ -280,7 +269,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 					{
 						def = TRUE;
 
-						pti = get_arg_in_braces(pti, buf, TRUE);
+						pti = get_arg_in_braces(ses, pti, buf, TRUE);
 
 						substitute(ses, buf, temp, flags_neol);
 					}
@@ -295,7 +284,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 						*ptt = 0;
 					}
 
-					pti = get_arg_at_brackets(pti, temp + strlen(temp));
+					pti = get_arg_at_brackets(ses, pti, temp + strlen(temp));
 
 					substitute(ses, temp, buf, flags_neol);
 
@@ -314,7 +303,11 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 			case '<':
 				if (HAS_BIT(flags, SUB_COL))
 				{
-					if (isdigit((int) pti[1]) && isdigit((int) pti[2]) && isdigit((int) pti[3]) && pti[4] == '>')
+					if (HAS_BIT(flags, SUB_CMP) && !strncmp(old, pti, 5))
+					{
+						pti += 5;
+					}
+					else if (isdigit((int) pti[1]) && isdigit((int) pti[2]) && isdigit((int) pti[3]) && pti[4] == '>')
 					{
 						if (pti[1] != '8' || pti[2] != '8' || pti[3] != '8')
 						{
@@ -357,7 +350,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 							pto--;
 							*pto++ = 'm';
 						}
-						pti += 5;
+						pti += sprintf(old, "<%c%c%c>", pti[1], pti[2], pti[3]);
 					}
 					else if (pti[1] >= 'a' && pti[1] <= 'f' && pti[2] >= 'a' && pti[2] <= 'f' && pti[3] >= 'a' && pti[3] <= 'f' && pti[4] == '>')
 					{
@@ -373,7 +366,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 						*pto++ = '0' + cnt % 100 / 10;
 						*pto++ = '0' + cnt % 10;
 						*pto++ = 'm';
-						pti += 5;
+						pti += sprintf(old, "<%c%c%c>", pti[1], pti[2], pti[3]);
 					}
 					else if (pti[1] >= 'A' && pti[1] <= 'F' && pti[2] >= 'A' && pti[2] <= 'F' && pti[3] >= 'A' && pti[3] <= 'F' && pti[4] == '>')
 					{
@@ -389,7 +382,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 						*pto++ = '0' + cnt % 100 / 10;
 						*pto++ = '0' + cnt % 10;
 						*pto++ = 'm';
-						pti += 5;
+						pti += sprintf(old, "<%c%c%c>", pti[1], pti[2], pti[3]);
 					}
 					else if (pti[1] == 'g' && isdigit((int) pti[2]) && isdigit((int) pti[3]) && pti[4] == '>')
 					{
@@ -405,7 +398,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 						*pto++ = '0' + cnt % 100 / 10;
 						*pto++ = '0' + cnt % 10;
 						*pto++ = 'm';
-						pti += 5;
+						pti += sprintf(old, "<%c%c%c>", pti[1], pti[2], pti[3]);
 					}
 					else if (pti[1] == 'G' && isdigit((int) pti[2]) && isdigit((int) pti[3]) && pti[4] == '>')
 					{
@@ -421,7 +414,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 						*pto++ = '0' + cnt % 100 / 10;
 						*pto++ = '0' + cnt % 10;
 						*pto++ = 'm';
-						pti += 5;
+						pti += sprintf(old, "<%c%c%c>", pti[1], pti[2], pti[3]);
 					}
 					else
 					{
@@ -466,7 +459,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 						continue;
 					}
 
-					pti = get_arg_in_braces(&pti[i], temp, FALSE);
+					pti = get_arg_in_braces(ses, &pti[i], temp, FALSE);
 
 					substitute(ses, temp, buf, flags_neol);
 
@@ -478,7 +471,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 
 					for (i = 1 ; i < 100 ; i++)
 					{
-						pte = get_arg_in_braces(pte, temp, TRUE);
+						pte = get_arg_in_braces(ses, pte, temp, TRUE);
 
 						RESTRING(gtd->vars[i], temp);
 
@@ -527,17 +520,13 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 
 						while (*ptt)
 						{
-#ifdef BIG5
-							if (*ptt & 0x80)
+							if (HAS_BIT(ses->flags, SES_FLAG_BIG5) && *ptt & 128 && ptt[1] != 0)
 							{
 								*pto++ = *ptt++;
-								if (*ptt)
-								{
-									*pto++ = *ptt++;
-								}
+								*pto++ = *ptt++;
 								continue;
 							}
-#endif
+
 							if (HAS_BIT(flags, SUB_SEC))
 							{
 								switch (*ptt)
@@ -644,7 +633,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 					{
 						def = TRUE;
 
-						pti = get_arg_in_braces(pti, buf, TRUE);
+						pti = get_arg_in_braces(ses, pti, buf, TRUE);
 
 						substitute(ses, buf, temp, flags_neol);
 					}
@@ -657,7 +646,7 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 						*ptt = 0;
 					}
 
-					pti = get_arg_at_brackets(pti, temp + strlen(temp));
+					pti = get_arg_at_brackets(ses, pti, temp + strlen(temp));
 
 					substitute(ses, temp, buf, flags_neol);
 
@@ -737,6 +726,10 @@ int substitute(struct session *ses, char *string, char *result, int flags)
 				}
 				break;
 
+			case ESCAPE:
+				*pto++ = *pti++;
+				break;
+
 			default:
 				if (HAS_BIT(flags, SUB_SEC) && !HAS_BIT(flags, SUB_ARG))
 				{
@@ -814,14 +807,14 @@ int check_one_regexp(struct session *ses, struct listnode *node, char *line, cha
 		str = line;
 	}	
 
-	return tintin_regexp(node->regex, str, exp, option, SUB_ARG);
+	return tintin_regexp(ses, node->regex, str, exp, option, SUB_ARG);
 }
 
 /*
 	Keep synched with tintin_regexp and tintin_regexp_compile
 */
 
-int tintin_regexp_check(char *exp)
+int tintin_regexp_check(struct session *ses, char *exp)
 {
 	if (*exp == '^')
 	{
@@ -830,13 +823,13 @@ int tintin_regexp_check(char *exp)
 
 	while (*exp)
 	{
-#ifdef BIG5
-		if (*exp & 0x80)
+
+		if (HAS_BIT(ses->flags, SES_FLAG_BIG5) && *exp & 128 && exp[1] != 0)
 		{
 			exp += 2;
 			continue;
 		}
-#endif		
+
 		switch (exp[0])
 		{
 			case '\\':
@@ -885,7 +878,7 @@ int tintin_regexp_check(char *exp)
 	return FALSE;
 }
 				
-int tintin_regexp(pcre *nodepcre, char *str, char *exp, int option, int flag)
+int tintin_regexp(struct session *ses, pcre *nodepcre, char *str, char *exp, int option, int flag)
 {
 	char out[BUFFER_SIZE], *pti, *pto;
 	int arg = 1, var = 1, fix = 0;
@@ -900,14 +893,13 @@ int tintin_regexp(pcre *nodepcre, char *str, char *exp, int option, int flag)
 
 	while (*pti)
 	{
-#ifdef BIG5
-		if (*pti & 0x80)
+		if (HAS_BIT(ses->flags, SES_FLAG_BIG5) && *pti & 128 && pti[1] != 0)
 		{
 			*pto++ = *pti++;
 			*pto++ = *pti++;
 			continue;
 		}
-#endif
+
 		switch (pti[0])
 		{
 			case '\\':
@@ -918,7 +910,7 @@ int tintin_regexp(pcre *nodepcre, char *str, char *exp, int option, int flag)
 			case '{':
 				gtd->args[up(var)] = up(arg);
 				*pto++ = '(';
-				pti = get_arg_in_braces(pti, pto, TRUE);
+				pti = get_arg_in_braces(ses, pti, pto, TRUE);
 				pto += strlen(pto);
 				*pto++ = ')';
 				break;
@@ -1079,7 +1071,7 @@ int tintin_regexp(pcre *nodepcre, char *str, char *exp, int option, int flag)
 	return regexp_compare(nodepcre, str, out, option, flag + fix);
 }
 
-pcre *tintin_regexp_compile(struct listnode *node, char *exp, int option)
+pcre *tintin_regexp_compile(struct session *ses, struct listnode *node, char *exp, int option)
 {
 	char out[BUFFER_SIZE], *pti, *pto;
 
@@ -1099,15 +1091,12 @@ pcre *tintin_regexp_compile(struct listnode *node, char *exp, int option)
 
 	while (*pti)
 	{
-
-#ifdef BIG5
-		if (*pti & 0x80)
+		if (HAS_BIT(ses->flags, SES_FLAG_BIG5) && *pti & 128 && pti[1] != 0)
 		{
 			*pto++ = *pti++;
 			*pto++ = *pti++;
 			continue;
 		}
-#endif
 		switch (pti[0])
 		{
 			case '\\':
@@ -1117,7 +1106,7 @@ pcre *tintin_regexp_compile(struct listnode *node, char *exp, int option)
 
 			case '{':
 				*pto++ = '(';
-				pti = get_arg_in_braces(pti, pto, TRUE);
+				pti = get_arg_in_braces(ses, pti, pto, TRUE);
 				while (*pto)
 				{
 					if (pto[0] == '$' || pto[0] == '@')
