@@ -38,68 +38,113 @@
 
 int is_abbrev(char *s1, char *s2)
 {
-	if (strlen(s2) < strlen(s1))
+	if (*s1 == 0)
 	{
-		return (FALSE);
+		return FALSE;
 	}
-	return (!strncasecmp(s2, s1, strlen(s1)));
+	return !strncasecmp(s2, s1, strlen(s1));
 }
 
 
 int is_color_code(char *str)
 {
-	while (*str)
+	if (str[0] == '<')
 	{
-		if (*str++ == '<')
+		if (!isalnum((int) str[1]) || !isalnum((int) str[2]) || !isalnum((int) str[3]) || str[4] != '>')
 		{
-			if (isalnum((int) *str++) && isalnum((int) *str++) && isalnum((int) *str++))
-			{
-				if (*str++ == '>')
-				{
-					continue;
-				}
-			}
+			return FALSE;
+		}
+		else if (str[1] >= '0' && str[1] <= '9' && str[2] >= '0' && str[2] <= '9' && str[3] >= '0' && str[3] <= '9')
+		{
+			return TRUE;
+		}
+		else if (str[1] >= 'a' && str[1] <= 'f' && str[2] >= 'a' && str[2] <= 'f' && str[3] >= 'a' && str[3] <= 'f')
+		{
+			return TRUE;
+		}
+		else if (str[1] >= 'A' && str[1] <= 'F' && str[2] >= 'A' && str[2] <= 'F' && str[3] >= 'A' && str[3] <= 'F')
+		{
+			return TRUE;
+		}
+		else if (str[1] == 'g' && str[1] <= '9' && str[2] >= '0' && str[2] <= '9' && str[3] >= '0' && str[3] <= '9')
+		{
+			return TRUE;
+		}
+		else if (str[1] == 'G' && str[1] <= '9' && str[2] >= '0' && str[2] <= '9' && str[3] >= '0' && str[3] <= '9')
+		{
+			return TRUE;
 		}
-		return FALSE;
 	}
-	return TRUE;
+	return FALSE;
 }
 
 /*
-	return TRUE if the string is a number
+	Keep synched with tintoi()
 */
 
 int is_number(char *str)
 {
-	int i = 0;
+	char *ptr = str;
+	int i = 1, d = 0;
 
-	if (str[i] == '-' || str[i] == '+')
-	{
-		i++;
-	}
-
-	if (!isdigit((int) str[i]))
+	if (*ptr == 0)
 	{
 		return FALSE;
 	}
 
-	for (i = 1 ; str[i] != 0 ; i++)
-	{
-		if (!isdigit((int) str[i]))
-		{
-			if (str[i] != '.')
-			{
-				return FALSE;
-			}
+	ptr = str + strlen(str);
 
-			for (i++ ; str[i] != 0 ; i++)
-			{
-				if (!isdigit((int) str[i]))
+	while (TRUE)
+	{
+		ptr--;
+
+		switch (*ptr)
+		{
+			case '0':
+			case '1':
+			case '2':
+			case '3':
+			case '4':
+			case '5':
+			case '6':
+			case '7':
+			case '8':
+			case '9':
+				break;
+
+			case '.':
+				if (d)
 				{
 					return FALSE;
 				}
-			}
-			return TRUE;
+				d = 1;
+				break;
+
+			case ':':
+				if (i == 4)
+				{
+					return FALSE;
+				}
+				i++;
+				break;
+
+			case '!':
+			case '~':
+			case '+':
+			case '-':
+				if (ptr != str)
+				{
+					return FALSE;
+				}
+				break;
+
+			default:
+				return FALSE;
+		}
+
+		if (ptr == str)
+		{
+			break;
 		}
 	}
 	return TRUE;
@@ -217,17 +262,20 @@ char *indent(int cnt)
 	return outbuf;
 }
 
-void cat_sprintf(char *dest, char *fmt, ...)
+int cat_sprintf(char *dest, char *fmt, ...)
 {
 	char buf[STRING_SIZE];
+	int size;
 
 	va_list args;
 
 	va_start(args, fmt);
-	vsprintf(buf, fmt, args);
+	size = vsprintf(buf, fmt, args);
 	va_end(args);
 
 	strcat(dest, buf);
+
+	return size;
 }
 
 void ins_sprintf(char *dest, char *fmt, ...)
@@ -275,12 +323,19 @@ void show_message(struct session *ses, int index, char *format, ...)
 	vsprintf(buf, format, args);
 
 	va_end(args);
-	
+
+	if (HAS_BIT(ses->flags, SES_FLAG_VERBOSELINE))
+	{
+		tintin_puts2(ses, buf);
+
+		pop_call();
+		return;
+	}
+
 	if (index == -1)
 	{
 		if (ses->input_level == 0)
 		{
-
 			tintin_puts2(ses, buf);
 		}
 		pop_call();
@@ -441,7 +496,7 @@ void tintin_puts3(struct session *ses, char *string)
 		return;
 	}
 
-	if (strip_vt102_strlen(ses->more_output) != 0)
+	if (strip_vt102_strlen(ses, ses->more_output) != 0)
 	{
 		sprintf(output, "\n%s", string);
 	}
@@ -493,7 +548,7 @@ void tintin_puts2(struct session *ses, char *string)
 		return;
 	}
 
-	if (strip_vt102_strlen(ses->more_output) != 0)
+	if (strip_vt102_strlen(ses, ses->more_output) != 0)
 	{
 		sprintf(output, "\n\033[0m%s\033[0m", string);
 	}
